# -*- coding: utf-8 -*-
#
# Copyright (c) 2016-2017 Ircam
# Copyright (c) 2016-2017 Guillaume Pellerin
# Copyright (c) 2016-2017 Emilie Zawadzki

# This file is part of mezzanine-organization.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

from django.utils.translation import ugettext_lazy as _


# source: http://www.englishclub.com/vocabulary/world-countries-nationality.htm
NATIONALITIES = (
    ('AF', _(u'Afghan')),
    ('AL', _(u'Albanian')),
    ('DZ', _(u'Algerian')),
    ('AD', _(u'Andorran')),
    ('AO', _(u'Angolan')),
    ('AR', _(u'Argentinian')),
    ('AM', _(u'Armenian')),
    ('AU', _(u'Australian')),
    ('AT', _(u'Austrian')),
    ('AZ', _(u'Azerbaijani')),
    ('BS', _(u'Bahamian')),
    ('BH', _(u'Bahraini')),
    ('BD', _(u'Bangladeshi')),
    ('BB', _(u'Barbadian')),
    ('BY', _(u'Belorussian')),
    ('BE', _(u'Belgian')),
    ('BZ', _(u'Belizian')),
    ('BJ', _(u'Beninese')),
    ('BT', _(u'Bhutanese')),
    ('BO', _(u'Bolivian')),
    ('BA', _(u'Bosnian')),
    ('BW', _(u'Botswanan')),
    ('BR', _(u'Brazilian')),
    ('GB', _(u'British')),
    ('BN', _(u'Bruneian')),
    ('BG', _(u'Bulgarian')),
    ('BF', _(u'Burkinese')),
    ('MM', _(u'Burmese')),
    ('BF', _(u'Burundian')),
    ('BI', _(u'Cambodian')),
    ('CM', _(u'Cameroonian')),
    ('CA', _(u'Canadian')),
    ('CV', _(u'Cape Verdean')),
    ('TD', _(u'Chadian')),
    ('CL', _(u'Chilean')),
    ('CN', _(u'Chinese')),
    ('CO', _(u'Colombian')),
    ('CG', _(u'Congolese')),
    ('CR', _(u'Costa Rican')),
    ('HR', _(u'Croatian')),
    ('CU', _(u'Cuban')),
    ('CY', _(u'Cypriot')),
    ('CZ', _(u'Czech')),
    ('DK', _(u'Danish')),
    ('DJ', _(u'Djiboutian')),
    ('DM', _(u'Dominican')),
    ('DO', _(u'Dominican')),
    ('EC', _(u'Ecuadorean')),
    ('EG', _(u'Egyptian')),
    ('SV', _(u'Salvadorean')),
    ('GB', _(u'English')),
    ('ER', _(u'Eritrean')),
    ('EE', _(u'Estonian')),
    ('ET', _(u'Ethiopian')),
    ('FJ', _(u'Fijian')),
    ('FI', _(u'Finnish')),
    ('FR', _(u'French')),
    ('GA', _(u'Gabonese')),
    ('GM', _(u'Gambian')),
    ('GE', _(u'Georgian')),
    ('DE', _(u'German')),
    ('GH', _(u'Ghanaian')),
    ('GR', _(u'Greek')),
    ('GD', _(u'Grenadian')),
    ('GT', _(u'Guatemalan')),
    ('GQ', _(u'Guinean')),
    ('GY', _(u'Guyanese')),
    ('HT', _(u'Haitian')),
    ('NL', _(u'Dutch')),
    ('HN', _(u'Honduran')),
    ('HU', _(u'Hungarian')),
    ('IS', _(u'Icelandic')),
    ('IO', _(u'Indian')),
    ('ID', _(u'Indonesian')),
    ('IR', _(u'Iranian')),
    ('IQ', _(u'Iraqi')),
    ('IE', _(u'Irish')),
    ('IL', _(u'Israeli')),
    ('IT', _(u'Italian')),
    ('JM', _(u'Jamaican')),
    ('JP', _(u'Japanese')),
    ('JO', _(u'Jordanian')),
    ('KZ', _(u'Kazakh')),
    ('KE', _(u'Kenyan')),
    ('KW', _(u'Kuwaiti')),
    ('LA', _(u'Laotian')),
    ('LV', _(u'Latvian')),
    ('LB', _(u'Lebanese')),
    ('LR', _(u'Liberian')),
    ('LY', _(u'Libyan')),
    ('LT', _(u'Lithuanian')),
    ('MK', _(u'Macedonian')),
    ('MG', _(u'Malagasay')),
    ('MW', _(u'Malawian')),
    ('MY', _(u'Malaysian')),
    ('MV', _(u'Maldivian')),
    ('ML', _(u'Malian')),
    ('MT', _(u'Maltese')),
    ('MR', _(u'Mauritanian')),
    ('MU', _(u'Mauritian')),
    ('MX', _(u'Mexican')),
    ('MD', _(u'Moldovan')),
    ('MC', _(u'Monacan')),
    ('MN', _(u'Mongolian')),
    ('ME', _(u'Montenegrin')),
    ('MA', _(u'Moroccan')),
    ('MZ', _(u'Mozambican')),
    ('NA', _(u'Namibian')),
    ('NP', _(u'Nepalese')),
    ('NI', _(u'Nicaraguan')),
    ('NE', _(u'Nigerien')),
    ('NG', _(u'Nigerian')),
    ('KP', _(u'North Korean')),
    ('NO', _(u'Norwegian')),
    ('OM', _(u'Omani')),
    ('PK', _(u'Pakistani')),
    ('PA', _(u'Panamanian')),
    ('PG', _(u'Guinean')),
    ('PY', _(u'Paraguayan')),
    ('PE', _(u'Peruvian')),
    ('PH', _(u'Philippine')),
    ('PL', _(u'Polish')),
    ('PT', _(u'Portuguese')),
    ('QA', _(u'Qatari')),
    ('RO', _(u'Romanian')),
    ('RU', _(u'Russian')),
    ('RW', _(u'Rwandan')),
    ('SA', _(u'Saudi')),
    ('AE', _(u'Scottish')),
    ('SN', _(u'Senegalese')),
    ('RS', _(u'Serbian')),
    ('SC', _(u'Seychellois')),
    ('SL', _(u'Sierra Leonian')),
    ('SG', _(u'Singaporean')),
    ('SK', _(u'Slovak')),
    ('SI', _(u'Slovenian')),
    ('SO', _(u'Somali')),
    ('ZA', _(u'South African')),
    ('KR', _(u'South Korean')),
    ('ES', _(u'Spanish')),
    ('LK', _(u'Sri Lankan')),
    ('SD', _(u'Sudanese')),
    ('SR', _(u'Surinamese')),
    ('SZ', _(u'Swazi')),
    ('SE', _(u'Swedish')),
    ('CH', _(u'Swiss')),
    ('SY', _(u'Syrian')),
    ('TW', _(u'Taiwanese')),
    ('TJ', _(u'Tadjik')),
    ('TZ', _(u'Tanzanian')),
    ('TH', _(u'Thai')),
    ('TG', _(u'Togolese')),
    ('TT', _(u'Trinidadian')),
    ('TN', _(u'Tunisian')),
    ('TR', _(u'Turkish')),
    ('TM', _(u'Turkmen')),
    ('TV', _(u'Tuvaluan')),
    ('UG', _(u'Ugandan')),
    ('UA', _(u'Ukrainian')),
    ('UY', _(u'Uruguayan')),
    ('UZ', _(u'Uzbek')),
    ('VU', _(u'Vanuatuan')),
    ('VE', _(u'Venezuelan')),
    ('VN', _(u'Vietnamese')),
    ('GB', _(u'Welsh')),
    ('YE', _(u'Yemeni')),
    ('ZM', _(u'Zambian')),
    ('ZW', _(u'Zimbabwean')),
)
